@@ -1,6 +1,6 @@
 from typing import Protocol
 
-from attr import attrib, attrs
+from attr import attrs
 
 
 class PositionProtocol(Protocol):
@@ -19,7 +19,7 @@ class PositionProtocol(Protocol):
     y: int
 
 
-@attrs(slots=True)
+@attrs(slots=True, auto_attribs=True)
 class Position:
     """
     A two dimensional representation of a point on a plain, that uses ``attrs`` to create a basic
@@ -33,5 +33,5 @@ class Position:
         The vertical location of the point.
     """
 
-    x = attrib(type=int)
-    y = attrib(type=int)
+    x: int
+    y: int
